package com.mirs.biz.service;

import java.util.List;
import com.mirs.biz.domain.EmiMeasurement;
import com.mirs.biz.dto.IndexSearchDTO;

/**
 * 测量数据Service接口
 * 
 * @author kk
 * @date 2025-04-24
 */
public interface IEmiMeasurementService 
{
    /**
     * 查询测量数据
     * 
     * @param id 测量数据主键
     * @return 测量数据
     */
    public EmiMeasurement selectEmiMeasurementById(Long id);

    /**
     * 查询测量数据列表
     * 
     * @param emiMeasurement 测量数据
     * @return 测量数据集合
     */
    public List<EmiMeasurement> selectEmiMeasurementList(EmiMeasurement emiMeasurement);

    /**
     * 新增测量数据
     * 
     * @param emiMeasurement 测量数据
     * @return 结果
     */
    public int insertEmiMeasurement(EmiMeasurement emiMeasurement);

    /**
     * 修改测量数据
     * 
     * @param emiMeasurement 测量数据
     * @return 结果
     */
    public int updateEmiMeasurement(EmiMeasurement emiMeasurement);

    /**
     * 批量删除测量数据
     * 
     * @param ids 需要删除的测量数据主键集合
     * @return 结果
     */
    public int deleteEmiMeasurementByIds(Long[] ids);

    /**
     * 删除测量数据信息
     * 
     * @param id 测量数据主键
     * @return 结果
     */
    public int deleteEmiMeasurementById(Long id);

    String importEmiMeasurement(List<EmiMeasurement> emiMeasurementList, boolean updateSupport, String operName);

    List getTemperatureK();
}
